==> qxmpp_0.3.92.orig.tar.gz: qxmpp-0.3.92/doc/html/search/functions_72.js <==
var searchData=
[
  ['reason',['reason',['../classQXmppJingleIq.html#a0109cfd1525f9ee69a40ae0ce3962d69',1,'QXmppJingleIq::reason()'],['../classQXmppJingleIq.html#a9027b28bc5f929ee415f0de50563cac7',1,'QXmppJingleIq::reason() const ']]],
  ['receiptid',['receiptId',['../classQXmppMessage.html#a3df33f75c06de9a3fbe3897ca89893db',1,'QXmppMessage']]],
  ['reconnectionmanager',['reconnectionManager',['../classQXmppClient.html#a90b0733ffa8b3d8a3922cb54bc6426cc',1,'QXmppClient']]],
  ['refusesubscription',['refuseSubscription',['../classQXmppRosterManager.html#a8942d10cdcdad0821f4ce75fe0ee583d',1,'QXmppRosterManager']]],
  ['remotedomain',['remoteDomain',['../classQXmppOutgoingServer.html#acf167e9cf078b1ee9ef80fd2d3ac0b83',1,'QXmppOutgoingServer']]],
  ['removecollections',['removeCollections',['../classQXmppArchiveManager.html#a3de27735449b3fb10a1e85032ed3e0b6',1,'QXmppArchiveManager']]],
  ['removeextension',['removeExtension',['../classQXmppClient.html#ae48477dc92abd66193789bfc60d16d62',1,'QXmppClient']]],
  ['removeitem',['removeItem',['../classQXmppRosterManager.html#a0ac3bd1ee2cbe8e99c3da55f9423fe20',1,'QXmppRosterManager']]],
  ['renameitem',['renameItem',['../classQXmppRosterManager.html#a65ecf5954b56e1d38be5b3554c4e3f30',1,'QXmppRosterManager']]],
  ['reopen',['reopen',['../classQXmppLogger.html#a18ebf48f34358d20dd57502a9db2f0c0',1,'QXmppLogger']]],
  ['requestclientvcard',['requestClientVCard',['../classQXmppVCardManager.html#a3f049d6356f93f5f8fa81a1c30ea5ba9',1,'QXmppVCardManager']]],
  ['requestconfiguration',['requestConfiguration',['../classQXmppMucRoom.html#ab20d3d15a70354d109d1f30a13c8c1df',1,'QXmppMucRoom']]],
  ['requestinfo',['requestInfo',['../classQXmppDiscoveryManager.html#a81facc7b29132ee7f13c26d8d441e611',1,'QXmppDiscoveryManager']]],
  ['requestitems',['requestItems',['../classQXmppDiscoveryManager.html#ac6b173d943634603beeb43c15609efe4',1,'QXmppDiscoveryManager']]],
  ['requestpermissions',['requestPermissions',['../classQXmppMucRoom.html#a8b7cb2b8755a8cd18bf0d98cb3c3a0aa',1,'QXmppMucRoom']]],
  ['requesttime',['requestTime',['../classQXmppEntityTimeManager.html#ab6cb76de7eb717bb8f332b7ed643fb7b',1,'QXmppEntityTimeManager']]],
  ['requestvcard',['requestVCard',['../classQXmppVCardManager.html#a71c114c5375575004bd1e2593aff0ba9',1,'QXmppVCardManager']]],
  ['requestversion',['requestVersion',['../classQXmppVersionManager.html#ae63fec70ad9b12cb585cb2d46b8e1406',1,'QXmppVersionManager']]],
  ['reserveports',['reservePorts',['../classQXmppIceComponent.html#a1fc342ff0fa196320b86a2c1413b33fc',1,'QXmppIceComponent']]],
  ['resource',['resource',['../classQXmppBindIq.html#ac6aa0a84579d18f28196301a774a6e42',1,'QXmppBindIq::resource()'],['../classQXmppConfiguration.html#ad6969bdce483c31e1196ffb0cca800f3',1,'QXmppConfiguration::resource()']]],
  ['responder',['responder',['../classQXmppJingleIq.html#ad77bd95c596dbef85b9d84ff72fb4716',1,'QXmppJingleIq']]],
  ['retrievecollection',['retrieveCollection',['../classQXmppArchiveManager.html#a079d1795b51ab24e00a7b10a6a0bba15',1,'QXmppArchiveManager']]],
  ['ringing',['ringing',['../classQXmppJingleIq.html#a2cc94c4e2e8dec892d8388aca47b0268',1,'QXmppJingleIq::ringing()'],['../classQXmppCall.html#ac661611e7d0bf5ebcdf56a28d60a95aa',1,'QXmppCall::ringing()']]],
  ['role',['role',['../classQXmppMucItem.html#af65444d3b29bbb8d78b4d25aa8f02894',1,'QXmppMucItem']]],
  ['roomadded',['roomAdded',['../classQXmppMucManager.html#a948446ebb49b07e772d8a70a0b8e71e6',1,'QXmppMucManager']]],
  ['rostermanager',['rosterManager',['../classQXmppClient.html#a6a0bb409bad66a4f5ea91056ee190ad4',1,'QXmppClient']]],
  ['rosterreceived',['rosterReceived',['../classQXmppRosterManager.html#a978cf900248b0ef144460bb52052ded8',1,'QXmppRosterManager']]]
];

==> qxmpp_0.4.92.orig.tar.gz: qxmpp-0.4.92/doc/html/search/functions_72.js <==
var searchData=
[
  ['readframes',['readFrames',['../classQXmppRtpVideoChannel.html#a2d2c5854406f34fedbd10d6096428493',1,'QXmppRtpVideoChannel']]],
  ['reason',['reason',['../classQXmppJingleIq.html#a0109cfd1525f9ee69a40ae0ce3962d69',1,'QXmppJingleIq::reason()'],['../classQXmppJingleIq.html#a9027b28bc5f929ee415f0de50563cac7',1,'QXmppJingleIq::reason() const '],['../classQXmppMucItem.html#a7b5574030b7bb253c23ccf46fffde87e',1,'QXmppMucItem::reason()']]],
  ['receiptid',['receiptId',['../classQXmppMessage.html#a3df33f75c06de9a3fbe3897ca89893db',1,'QXmppMessage']]],
  ['refusesubscription',['refuseSubscription',['../classQXmppRosterManager.html#a8942d10cdcdad0821f4ce75fe0ee583d',1,'QXmppRosterManager']]],
  ['remotedomain',['remoteDomain',['../classQXmppOutgoingServer.html#acf167e9cf078b1ee9ef80fd2d3ac0b83',1,'QXmppOutgoingServer']]],
  ['removecollections',['removeCollections',['../classQXmppArchiveManager.html#a3de27735449b3fb10a1e85032ed3e0b6',1,'QXmppArchiveManager']]],
  ['removeextension',['removeExtension',['../classQXmppClient.html#ae48477dc92abd66193789bfc60d16d62',1,'QXmppClient']]],
  ['removeitem',['removeItem',['../classQXmppRosterManager.html#a0ac3bd1ee2cbe8e99c3da55f9423fe20',1,'QXmppRosterManager']]],
  ['renameitem',['renameItem',['../classQXmppRosterManager.html#a65ecf5954b56e1d38be5b3554c4e3f30',1,'QXmppRosterManager']]],
  ['reopen',['reopen',['../classQXmppLogger.html#a18ebf48f34358d20dd57502a9db2f0c0',1,'QXmppLogger']]],
  ['requestclientvcard',['requestClientVCard',['../classQXmppVCardManager.html#a3f049d6356f93f5f8fa81a1c30ea5ba9',1,'QXmppVCardManager']]],
  ['requestconfiguration',['requestConfiguration',['../classQXmppMucRoom.html#ab20d3d15a70354d109d1f30a13c8c1df',1,'QXmppMucRoom']]],
  ['requestinfo',['requestInfo',['../classQXmppDiscoveryManager.html#a81facc7b29132ee7f13c26d8d441e611',1,'QXmppDiscoveryManager']]],
  ['requestitems',['requestItems',['../classQXmppDiscoveryManager.html#ac6b173d943634603beeb43c15609efe4',1,'QXmppDiscoveryManager']]],
  ['requestpermissions',['requestPermissions',['../classQXmppMucRoom.html#a8b7cb2b8755a8cd18bf0d98cb3c3a0aa',1,'QXmppMucRoom']]],
  ['requesttime',['requestTime',['../classQXmppEntityTimeManager.html#ab6cb76de7eb717bb8f332b7ed643fb7b',1,'QXmppEntityTimeManager']]],
  ['requestvcard',['requestVCard',['../classQXmppVCardManager.html#a71c114c5375575004bd1e2593aff0ba9',1,'QXmppVCardManager']]],
  ['requestversion',['requestVersion',['../classQXmppVersionManager.html#ae63fec70ad9b12cb585cb2d46b8e1406',1,'QXmppVersionManager']]],
  ['reserveports',['reservePorts',['../classQXmppIceComponent.html#a1fc342ff0fa196320b86a2c1413b33fc',1,'QXmppIceComponent']]],
  ['resource',['resource',['../classQXmppBindIq.html#ac6aa0a84579d18f28196301a774a6e42',1,'QXmppBindIq::resource()'],['../classQXmppConfiguration.html#ad6969bdce483c31e1196ffb0cca800f3',1,'QXmppConfiguration::resource()']]],
  ['responder',['responder',['../classQXmppJingleIq.html#ad77bd95c596dbef85b9d84ff72fb4716',1,'QXmppJingleIq']]],
  ['retrievecollection',['retrieveCollection',['../classQXmppArchiveManager.html#a079d1795b51ab24e00a7b10a6a0bba15',1,'QXmppArchiveManager']]],
  ['ringing',['ringing',['../classQXmppJingleIq.html#a2cc94c4e2e8dec892d8388aca47b0268',1,'QXmppJingleIq::ringing()'],['../classQXmppCall.html#ac661611e7d0bf5ebcdf56a28d60a95aa',1,'QXmppCall::ringing()']]],
  ['role',['role',['../classQXmppMucItem.html#af65444d3b29bbb8d78b4d25aa8f02894',1,'QXmppMucItem']]],
  ['roomadded',['roomAdded',['../classQXmppMucManager.html#a948446ebb49b07e772d8a70a0b8e71e6',1,'QXmppMucManager']]],
  ['rostermanager',['rosterManager',['../classQXmppClient.html#a6a0bb409bad66a4f5ea91056ee190ad4',1,'QXmppClient']]],
  ['rosterreceived',['rosterReceived',['../classQXmppRosterManager.html#a978cf900248b0ef144460bb52052ded8',1,'QXmppRosterManager']]]
];
